# py-and-id
#### Piping and Instrumentation Diagram but it's Python code.

## What is Propylean
Piping and Instrumentation Diagrams or P&IDs are complicated drawings describing a processing plant. We are making it more complicated by building it into a Python code.